==> haskell-flexible-defaults-0.0.3-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-flexible-defaults.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 flexible-defaults
version:              0.0.3
visibility:           public
id:                   flexible-defaults-0.0.3-4ZF586bu1yCSU0JqSiqjQ
key:                  flexible-defaults-0.0.3-4ZF586bu1yCSU0JqSiqjQ
license:              LicenseRef-PublicDomain
maintainer:           Peter Simons <simons@cryp.to>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/peti/flexible-defaults
synopsis:
    Generate default function implementations for complex type classes.

description:
    Template Haskell code to implement default implementations
    for type-class functions based on which functions are
    already implemented.  Currently extremely crude but
    still fairly effective.

    When defining a type class with many functions, each
    of which can be implemented based on arbitrary subsets
    of the others, the standard default-implementation
    concept breaks down quite badly.  This library provides
    a system by which more complex rules can be described
    for choosing default implementations based on which
    ones the user supplies.  These implementations can
    additionally be given \"suitability scores\", so that
    when multiple possible choices could be made, the
    library can choose the \"best\" one.

category:             Code Generation, Template Haskell
abi:                  441ba152621345055e67ebb2c006ab70
exposed:              True
exposed-modules:      Language.Haskell.TH.FlexibleDefaults
hidden-modules:
    Language.Haskell.TH.FlexibleDefaults.DSL
    Language.Haskell.TH.FlexibleDefaults.Solve

import-dirs:          /usr/lib/ghc-9.2.8/site-local/flexible-defaults-0.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/flexible-defaults-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-flexible-defaults
hs-libraries:         HSflexible-defaults-0.0.3-4ZF586bu1yCSU0JqSiqjQ
depends:
    base-4.16.4.0 containers-0.6.5.1 template-haskell-2.18.0.0
    th-extras-0.0.0.8-DtNQysEWagu8dFfDohwmYD transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-flexible-defaults/html/flexible-defaults.haddock

haddock-html:         /usr/share/doc/haskell-flexible-defaults/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-flexible-defaults-0.0.3-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-flexible-defaults.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 flexible-defaults
version:              0.0.3
visibility:           public
id:                   flexible-defaults-0.0.3-3r1f6nWYl2w8HihSLU45to
key:                  flexible-defaults-0.0.3-3r1f6nWYl2w8HihSLU45to
license:              LicenseRef-PublicDomain
maintainer:           Peter Simons <simons@cryp.to>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/peti/flexible-defaults
synopsis:
    Generate default function implementations for complex type classes.

description:
    Template Haskell code to implement default implementations
    for type-class functions based on which functions are
    already implemented.  Currently extremely crude but
    still fairly effective.

    When defining a type class with many functions, each
    of which can be implemented based on arbitrary subsets
    of the others, the standard default-implementation
    concept breaks down quite badly.  This library provides
    a system by which more complex rules can be described
    for choosing default implementations based on which
    ones the user supplies.  These implementations can
    additionally be given \"suitability scores\", so that
    when multiple possible choices could be made, the
    library can choose the \"best\" one.

category:             Code Generation, Template Haskell
abi:                  12a5f5d2b891702349aec43644c44022
exposed:              True
exposed-modules:      Language.Haskell.TH.FlexibleDefaults
hidden-modules:
    Language.Haskell.TH.FlexibleDefaults.DSL
    Language.Haskell.TH.FlexibleDefaults.Solve

import-dirs:          /usr/lib/ghc-9.4.8/site-local/flexible-defaults-0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/flexible-defaults-0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/flexible-defaults-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-flexible-defaults
hs-libraries:         HSflexible-defaults-0.0.3-3r1f6nWYl2w8HihSLU45to
depends:
    base-4.17.2.1 containers-0.6.7 template-haskell-2.19.0.0
    th-extras-0.0.0.8-FEcQcU1sgMW8o9UQ45Nr0t transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-flexible-defaults/html/flexible-defaults.haddock

haddock-html:         /usr/share/doc/haskell-flexible-defaults/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
